@@ -1,11 +1,12 @@
 from __future__ import annotations
 
+from collections.abc import Mapping
 from contextlib import suppress
 from datetime import timezone
 from functools import partial
 from os.path import realpath
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, ClassVar, ForwardRef, Generic, Mapping, TypeVar, cast
+from typing import TYPE_CHECKING, Any, ClassVar, ForwardRef, Generic, TypeVar, cast
 from uuid import NAMESPACE_DNS, uuid1, uuid3, uuid5
 
 from typing_extensions import Literal, get_args
@@ -14,8 +15,8 @@ from polyfactory.exceptions import MissingDependencyException
 from polyfactory.factories.base import BaseFactory, BuildContext
 from polyfactory.factories.base import BuildContext as BaseBuildContext
 from polyfactory.field_meta import Constraints, FieldMeta, Null
-from polyfactory.utils.deprecation import check_for_deprecated_parameters
 from polyfactory.utils.helpers import unwrap_new_type, unwrap_optional
+from polyfactory.utils.model_coverage import CoverageContainer
 from polyfactory.utils.normalize_type import normalize_type
 from polyfactory.utils.predicates import is_annotated, is_optional, is_safe_subclass, is_union
 from polyfactory.utils.types import NoneType
@@ -90,8 +91,8 @@ except ImportError:
 
 if TYPE_CHECKING:
     from collections import abc
-    from random import Random
-    from typing import Callable, Sequence
+    from collections.abc import Iterable, Mapping, Sequence
+    from typing import Callable
 
     from typing_extensions import NotRequired, TypeGuard
 
@@ -120,7 +121,6 @@ class PydanticFieldMeta(FieldMeta):
         *,
         name: str,
         annotation: type,
-        random: Random | None = None,
         default: Any = ...,
         children: list[FieldMeta] | None = None,
         constraints: PydanticConstraints | None = None,
@@ -129,7 +129,6 @@ class PydanticFieldMeta(FieldMeta):
         super().__init__(
             name=name,
             annotation=annotation,
-            random=random,
             default=default,
             children=children,
             constraints=constraints,
@@ -142,32 +141,15 @@ class PydanticFieldMeta(FieldMeta):
         field_name: str,
         field_info: FieldInfo,
         use_alias: bool,
-        random: Random | None = None,
-        randomize_collection_length: bool | None = None,
-        min_collection_length: int | None = None,
-        max_collection_length: int | None = None,
     ) -> PydanticFieldMeta:
         """Create an instance from a pydantic field info.
 
         :param field_name: The name of the field.
         :param field_info: A pydantic FieldInfo instance.
         :param use_alias: Whether to use the field alias.
-        :param random: A random.Random instance.
-        :param randomize_collection_length: Whether to randomize collection length.
-        :param min_collection_length: Minimum collection length.
-        :param max_collection_length: Maximum collection length.
 
         :returns: A PydanticFieldMeta instance.
         """
-        check_for_deprecated_parameters(
-            "2.11.0",
-            parameters=(
-                ("randomize_collection_length", randomize_collection_length),
-                ("min_collection_length", min_collection_length),
-                ("max_collection_length", max_collection_length),
-                ("random", random),
-            ),
-        )
         field_info = FieldInfo.merge_field_infos(
             field_info,
             FieldInfo.from_annotation(normalize_type(field_info.annotation)),
@@ -242,32 +224,14 @@ class PydanticFieldMeta(FieldMeta):
         cls,
         model_field: ModelField,  # pyright: ignore[reportGeneralTypeIssues]
         use_alias: bool,
-        randomize_collection_length: bool | None = None,
-        min_collection_length: int | None = None,
-        max_collection_length: int | None = None,
-        random: Random | None = None,
     ) -> PydanticFieldMeta:
         """Create an instance from a pydantic model field.
         :param model_field: A pydantic ModelField.
         :param use_alias: Whether to use the field alias.
-        :param randomize_collection_length: A boolean flag whether to randomize collections lengths
-        :param min_collection_length: Minimum number of elements in randomized collection
-        :param max_collection_length: Maximum number of elements in randomized collection
-        :param random: An instance of random.Random.
 
         :returns: A PydanticFieldMeta instance.
 
         """
-        check_for_deprecated_parameters(
-            "2.11.0",
-            parameters=(
-                ("randomize_collection_length", randomize_collection_length),
-                ("min_collection_length", min_collection_length),
-                ("max_collection_length", max_collection_length),
-                ("random", random),
-            ),
-        )
-
         if model_field.default is not Undefined:
             default_value = model_field.default
         elif callable(model_field.default_factory):
@@ -417,8 +381,9 @@ class ModelFactory(Generic[T], BaseFactory[T]):
         "__use_examples__",
     )
 
-    def __init_subclass__(cls, *args: Any, **kwargs: Any) -> None:
-        super().__init_subclass__(*args, **kwargs)
+    @classmethod
+    def _init_model(cls) -> None:
+        super()._init_model()
 
         model = getattr(cls, "__model__", None)
         if model is None:
@@ -459,14 +424,14 @@ class ModelFactory(Generic[T], BaseFactory[T]):
                     for field in cls.__model__.__fields__.values()
                 ]
             else:
+                use_alias = cls.__model__.model_config.get("validate_by_name", False) or cls.__model__.model_config.get(
+                    "populate_by_name", False
+                )
                 cls._fields_metadata = [
                     PydanticFieldMeta.from_field_info(
                         field_info=field_info,
                         field_name=field_name,
-                        use_alias=not cls.__model__.model_config.get(  # pyright: ignore[reportGeneralTypeIssues]
-                            "populate_by_name",
-                            False,
-                        ),
+                        use_alias=not use_alias,
                     )
                     for field_name, field_info in cls.__model__.model_fields.items()  # pyright: ignore[reportGeneralTypeIssues]
                 ]
@@ -577,7 +542,7 @@ class ModelFactory(Generic[T], BaseFactory[T]):
 
     @classmethod
     def coverage(cls, factory_use_construct: bool = False, **kwargs: Any) -> abc.Iterator[T]:
-        """Build a batch of the factory's Meta.model will full coverage of the sub-types of the model.
+        """Build a batch of the factory's Meta.model with full coverage of the sub-types of the model.
 
         :param kwargs: Any kwargs. If field_meta names are set in kwargs, their values will be used.
 
@@ -695,6 +660,33 @@ class ModelFactory(Generic[T], BaseFactory[T]):
         mapping.update(super().get_provider_map())
         return mapping
 
+    @classmethod
+    def get_field_value_coverage(
+        cls,
+        field_meta: FieldMeta,
+        field_build_parameters: Any | None = None,
+        build_context: BuildContext | None = None,
+    ) -> Iterable[Any]:
+        """Return a field value on the subclass if existing, otherwise returns a mock value.
+
+        :param field_meta: FieldMeta instance.
+        :param field_build_parameters: Any build parameters passed to the factory as kwarg values.
+        :param build_context: BuildContext data for current build.
+
+        :returns: An iterable of values.
+
+        """
+        if cls.is_ignored_type(field_meta.annotation):
+            return
+
+        if cls.__use_examples__:
+            examples = getattr(field_meta, "examples", None) or []
+            if len(examples) > 0:
+                yield CoverageContainer(examples)
+                return
+
+        yield from super().get_field_value_coverage(field_meta, field_build_parameters, build_context)
+
 
 def _is_pydantic_v1_model(model: Any) -> TypeGuard[BaseModelV1]:
     return is_safe_subclass(model, BaseModelV1)
